<template>
    <div class="system-role-container">
        <el-card shadow="hover">
            <div class="system-user-search mb15">
                <!--                <div class="basic-line">-->
                <!--                    <span>风险等级：</span>-->
                <!--                    <el-select v-model="checkUnitData.params.riskLevel" clearable filterable class="input-box" placeholder="请选择风险等级">-->
                <!--                        <el-option v-for="item in levelList" :key="item.id" :label="item.name" :value="item.id"></el-option>-->
                <!--                    </el-select>-->
                <!--                </div>-->
                <!--                <div class="basic-line">-->
                <!--                    <span>部门：</span>-->
                <!--                    <el-cascader :options="departmentList" :props="{ emitPath: false, checkStrictly: true, value: 'depId', label: 'depName' }" placeholder="请选择部门" clearable filterable class="input-box" v-model="checkUnitData.params.depId"> </el-cascader>-->
                <!--                </div>-->
                <el-button size="default" type="primary" class="ml10" v-throttle @click="handleSearch">
                    <el-icon>
                        <ele-Search />
                    </el-icon>
                    查询
                </el-button>
                <el-button size="default" type="success" class="ml10" @click="onOpenDialogRef('新增', '')">
                    <el-icon>
                        <ele-FolderAdd />
                    </el-icon>
                    新增排查单元
                </el-button>
            </div>
            <el-table :data="checkUnitData.data" style="width: 100%">
                <el-table-column type="index" label="序号" width="60" />
                <el-table-column prop="taskUnitName" label="任务单元名称" show-overflow-tooltip></el-table-column>
                <el-table-column prop="note" label="任务单元说明" show-overflow-tooltip></el-table-column>
                <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtCreate" label="创建时间" show-overflow-tooltip></el-table-column>
                <el-table-column prop="lastEditUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                <el-table-column prop="gmtModitify" label="最后修改时间" show-overflow-tooltip></el-table-column>
                <el-table-column label="操作" width="200" align="center">
                    <template #default="scope">
                        <el-button size="small" text type="primary" :icon="View" @click="onOpenDialogRef('查看', scope.row)">查看</el-button>
                        <el-button size="small" text type="primary" :icon="Edit" @click="onOpenDialogRef('修改', scope.row)">修改</el-button>
                        <el-button size="small" text type="danger" :icon="Delete" @click="onDelcheckUnit(scope.row)">删除</el-button>
                    </template>
                </el-table-column>
            </el-table>
            <br />
            <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="checkUnitData.params.pageIndex" background v-model:page-size="checkUnitData.params.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="checkUnitData.total" class="page-position"> </el-pagination>
            <br />
            <br />
        </el-card>
        <checkUnitDialog ref="checkUnitDialogRef" @refreshCheckUnit="initCheckUnitTableData" />
    </div>
</template>

<script lang="ts">
import { toRefs, reactive, onMounted, ref, defineComponent } from 'vue';
import { ElMessageBox, ElMessage } from 'element-plus';
import checkUnitDialog from './components/checkUnitDialog.vue';
import { checkUnitApi } from '/@/api/doublePreventSystem/checkUnit/index.ts';
import { Edit, Delete, View } from '@element-plus/icons-vue';

// 定义接口来定义对象的类型
interface TableData {
    roleName: string;
    roleSign: string;
    describe: string;
    sort: number;
    status: boolean;
    createTime: string;
}
interface TableDataState {
    checkUnitData: {
        data: Array<TableData>;
        total: number;
        loading: boolean;
        params: {
            pageIndex: number;
            pageSize: number;
            taskUnitId: number | null;
        };
    };
}

export default defineComponent({
    name: 'index',
    components: { checkUnitDialog, Edit, Delete, View },
    setup() {
        const checkUnitDialogRef = ref();
        const state = reactive<TableDataState>({
            checkUnitData: {
                data: [],
                total: 0,
                loading: false,
                params: {
                    pageIndex: 1,
                    pageSize: 10,
                    taskUnitId: null
                }
            }
        });
        // 初始化表格数据
        const initCheckUnitTableData = async () => {
            let res = await checkUnitApi().getCheckUnitList(state.checkUnitData.params);
            if (res.data.code === '200') {
                state.checkUnitData.data = res.data.data;
                state.checkUnitData.total = res.data.count;
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        };

        // 打开生产装置弹窗
        const onOpenDialogRef = (type: string, value: any) => {
            checkUnitDialogRef.value.openCheckUnitDialog(type, value);
        };
        // 删除角色
        const onDelCheckUnit = (row: any) => {
            ElMessageBox.confirm(`此操作将永久删除该条生产装置：“${row.produceDeviceName}”，是否继续?`, '提示', {
                confirmButtonText: '确认',
                cancelButtonText: '取消',
                type: 'warning'
            })
                .then(async () => {
                    let res = await checkUnitApi().deleteCheckUnit({ id: row.id });
                    if (res.data.code === '200') {
                        ElMessage({
                            type: 'success',
                            duration: 2000,
                            message: '删除成功'
                        });
                        await initCheckUnitTableData();
                    } else {
                        ElMessage({
                            type: 'warning',
                            message: res.data.msg
                        });
                    }
                })
                .catch(() => {});
        };

        const handleSearch = () => {
            initCheckUnitTableData();
        };
        // 分页改变
        const onHandleSizeChange = (val: number) => {
            state.checkUnitData.params.pageSize = val;
            initCheckUnitTableData();
        };
        // 分页改变
        const onHandleCurrentChange = (val: number) => {
            state.checkUnitData.params.pageIndex = val;
            initCheckUnitTableData();
        };
        // 页面加载时
        onMounted(() => {
            initCheckUnitTableData();
        });

        return {
            Edit,
            Delete,
            View,
            handleSearch,
            onOpenDialogRef,
            onHandleSizeChange,
            onDelCheckUnit,
            onHandleCurrentChange,
            checkUnitDialog,
            checkUnitDialogRef,
            initCheckUnitTableData,
            ...toRefs(state)
        };
    }
});
</script>

<style scoped>
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
